# VDG (VCB-S Draft Gen)

![MIT License](https://img.shields.io/badge/license-MIT-blue.svg)
[![Deploy to PyPI](https://github.com/diazchika/vdg/actions/workflows/python-publish.yml/badge.svg)](https://github.com/diazchika/vdg/actions/workflows/python-publish.yml)

## Introduction

主要是使用 Jinja2 对 HTML 模版进行填充以达到生成发布稿的效果。只需要把发布信息填写在 YAML 文件里就可以生成发布稿（并不是终稿）✌️。

总之就是一道大型填空题。

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.
